        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 26 <strong>control</strong><br>0,3,5,7,9,11,15,19,20,21,24,25,27,28,30,33,34,36,37,38,41,43,45,46,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,2,4,6,8,10,12,13,14,16,17,18,22,23,26,29,31,32,35,39,40,42,44,47,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 26 <strong>control</strong><br>0,3,5,7,9,11,15,19,20,21,24,25,27,28,30,33,34,36,37,38,41,43,45,46,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,2,4,6,8,10,12,13,14,16,17,18,22,23,26,29,31,32,35,39,40,42,44,47,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 26 <strong>control</strong><br>0,3,5,7,9,11,15,19,20,21,24,25,27,28,30,33,34,36,37,38,41,43,45,46,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,2,4,6,8,10,12,13,14,16,17,18,22,23,26,29,31,32,35,39,40,42,44,47,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 26 <strong>control</strong><br>0,3,5,7,9,11,15,19,20,21,24,25,27,28,30,33,34,36,37,38,41,43,45,46,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,2,4,6,8,10,12,13,14,16,17,18,22,23,26,29,31,32,35,39,40,42,44,47,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 26 <strong>control</strong><br>0,3,5,7,9,11,15,19,20,21,24,25,27,28,30,33,34,36,37,38,41,43,45,46,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260717 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 25 <br>1,2,4,6,8,10,12,13,14,16,17,18,22,23,26,29,31,32,35,39,40,42,44,47,48';}
}
